==> docfbe_2_2_33_59.zip: docfbe_2_2_33_59/source/TCFbECell.cpp <==
/*
    TCFbECell.cpp    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbECell.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^i肳ĂȂgNX𐶐
__fastcall TCFbECell::TCFbECell(void)
    : TObject()
{
    this->Enabled = false;
    this->FValue = 0.0;
    this->Rank = -1;
}

//---------------------------------------------------------------------------
// RXgN^i肳Ă郁gNX𐶐
__fastcall TCFbECell::TCFbECell(double value)
    : TObject()
{
    this->SetValue(value);
}

//---------------------------------------------------------------------------
// Rs[RXgN^
__fastcall TCFbECell::TCFbECell(TCFbECell* Source)
{
    this->Assign(Source);
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbECell::~TCFbECell()
{
}

//---------------------------------------------------------------------------
// this ̊el Source ̊el
void __fastcall TCFbECell::Assign(TCFbECell* Source)
{
    this->Enabled = Source->Enabled;
    this->FValue = Source->FValue;
    this->Rank = Source->Rank;
}

//---------------------------------------------------------------------------
// ȉCprotected \bh̒`
//---------------------------------------------------------------------------
// Value  Set ANZT
void __fastcall TCFbECell::SetValue(double value)
{
    this->Enabled = true;
    this->FValue = value;
}

//---------------------------------------------------------------------------
// Value  Get ANZT
double __fastcall TCFbECell::GetValue()
{
    if (!this->Enabled) {
        throw EInvalidArgument("The cell's value is unavailable.");
    }

    return this->FValue;
}

//---------------------------------------------------------------------------

==> docfbe_2_3_36_63.zip: docfbe_2_3_36_63/source/TCFbECell.cpp <==
/*
    TCFbECell.cpp    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbECell.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^i肳ĂȂgNX𐶐
__fastcall TCFbECell::TCFbECell(void)
    : TObject()
{
    this->FEnabled = false;
    this->FValue = 0.0;
    this->FRank = -1;
}

//---------------------------------------------------------------------------
// RXgN^i肳Ă郁gNX𐶐
__fastcall TCFbECell::TCFbECell(double value)
    : TObject()
{
    this->FEnabled = true;
    this->FValue = value;
    this->FRank = -1;
}

//---------------------------------------------------------------------------
// Rs[RXgN^
__fastcall TCFbECell::TCFbECell(TCFbECell* Source)
{
    this->Assign(Source);
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbECell::~TCFbECell()
{
}

//---------------------------------------------------------------------------
// this ̊el Source ̊el
void __fastcall TCFbECell::Assign(TCFbECell* Source)
{
    this->FEnabled = Source->FEnabled;
    this->FValue = Source->FValue;
    this->FRank = Source->FRank;
}

//---------------------------------------------------------------------------
// ȉCprotected \bh̒`
//---------------------------------------------------------------------------
